@@ -5,7 +5,7 @@
 import glob, sys, os
 
 def getVideoFilesFromFolder(dirPath):
-	types = (dirPath+os.sep+'*.avi', dirPath+os.sep+'*.mkv', dirPath+os.sep+'*.mp4', dirPath+os.sep+'*.mp3', dirPath+os.sep+'*.flac', dirPath+os.sep+'*.ogg') # the tuple of file types
+	types = (dirPath+os.sep+'*.webm', dirPath+os.sep+'*.avi', dirPath+os.sep+'*.mkv', dirPath+os.sep+'*.mp4', dirPath+os.sep+'*.mp3', dirPath+os.sep+'*.flac', dirPath+os.sep+'*.ogg') # the tuple of file types
 	files_grabbed = []
 	for files in types:
 		files_grabbed.extend(glob.glob(files))
@@ -18,7 +18,7 @@ def main(argv):
 		channels = int(argv[3])
 	
 		for f in files:
-			ffmpegString = 'avconv -i ' + '\"' + f + '\"' + ' -ar ' + str(samplingRate) + ' -ac ' + str(channels) + ' ' + '\"' + os.path.splitext(f)[0] + '\"' + '.wav' 
+			ffmpegString = 'ffmpeg -i ' + '\"' + f + '\"' + ' -ar ' + str(samplingRate) + ' -ac ' + str(channels) + ' ' + '\"' + os.path.splitext(f)[0] + '\"' + '.wav' 
 			os.system(ffmpegString)
 
 if __name__ == '__main__':
